@@ -423,7 +423,7 @@ static void setlevel(int n) {
   level = n;
 }
 
-static void setmode(int n) {
+static void set_mode(int n) {
   funmode = (n != 0);
 }
 
@@ -597,7 +597,7 @@ static void doserverstuff() {
 	break;
 
       case OP_MODE:
-	setmode(buf[2]);
+	set_mode(buf[2]);
 	break;
       
       case OP_BADVERS:
@@ -779,7 +779,7 @@ int main(int argc, char *argv[]) {
     }
     printf("\naverage lines: %d, average bricks: %d\n", (totallines+8)/16,
             (totalbricks + 8)/16);
-    printf("max lines: %d, max bricks: %d\n", maxlines+64, maxbricks);
+    printf("max lines: %d, max bricks: %d\n", maxlines, maxbricks);
     exit(0);
   }
 
