@@ -4,7 +4,7 @@
  *   Copyright (C) 1996 Roger Espel Llima <roger.espel.llima@pobox.com>
  *
  *   Started: 10 Oct 1996
- *   Version: 1.13
+ *   Version: 1.15
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
  *
  */
 
-#define VERSION "1.13"
+#define VERSION "1.15"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -463,6 +463,8 @@ void getnumresource(char *r, int *i) {
 }
 
 void getresources() {
+  char *s;
+
   if (!keysspecified) {
     getkeyresource("quitKey", &quit_key);
     getkeyresource("startKey", &start_key);
@@ -500,6 +502,10 @@ void getresources() {
   getnumresource("scrollLines", &hscroll);
   if (hscroll < 3 || hscroll > 30)
     hscroll = 10;
+
+  s = XGetDefault(display, "xtris", "name");
+  if (s)
+    strncpy(me.nick, s, MAXNICKLEN);
 }
 
 int GetColor(char *s) {
@@ -804,7 +810,6 @@ void WriteXY(int x, int y, char *txt) {
 void UpdateWinSize() {
   XSizeHints szh;
 
-  XResizeWindow(display, win, width, height);
   szh.flags = PMinSize | PMaxSize | PSize | PResizeInc;
   szh.min_width = width;
   szh.min_height = height;
@@ -813,6 +818,7 @@ void UpdateWinSize() {
   szh.width_inc = 1;
   szh.height_inc = 1;
   XSetWMProperties(display, win, NULL, NULL, NULL, 0, &szh, NULL, NULL);
+  XResizeWindow(display, win, width, height);
 }
 
 struct button *DeclareButton(int x, int y, int w, int h, int down, int flash,
@@ -1537,7 +1543,6 @@ void msgfrom(struct user *u, char *s) {
       height += HSCROLLRESIZE;
       visiblemsgs = 1;
       UpdateWinSize();
-      redrawall();
     }
   }
 }
@@ -1568,7 +1573,6 @@ void c_txt() {
     visiblemsgs = 1;
   }
   UpdateWinSize();
-  redrawall();
 }
 
 void c_zero() {
@@ -1668,7 +1672,7 @@ void setlevel(int n) {
   ToggleDown(leveltogs[n]);
 }
 
-void setmode(int n) {
+void set_mode(int n) {
   funmode = (n != 0);
   if (funmode)
     ChangeButtonAppearance(modebutton, -1, "fuN", -1);
@@ -1688,7 +1692,7 @@ void sendlevel(int n) {
 
 void sendmode(int n) {
   if (standalone)
-    setmode(n);
+    set_mode(n);
   else {
     buf[1] = OP_MODE;
     buf[2] = n;
@@ -1836,6 +1840,9 @@ void doevent(XEvent *xev) {
   struct user *u;
 
   switch(xev->type) {
+    case ConfigureNotify:
+      redrawall();
+      break;
     case Expose:
       if (xev->xexpose.count == 0)
 	redrawall();
@@ -2136,7 +2143,8 @@ void waitfor(int delay) {
   till.tv_usec += delay;
   tvnormal(till);
 
-  while (XCheckWindowEvent(display, win, ExposureMask|KeyPressMask|ButtonPressMask|StructureNotifyMask, &xev)) {
+  while (XEventsQueued(display, QueuedAfterReading) > 0) {
+    XNextEvent(display, &xev);
     doevent(&xev);
     gettimeofday(&now, NULL);
   }
@@ -2177,8 +2185,10 @@ void waitfor(int delay) {
       FD_ZERO(&rfds);
 
     if (FD_ISSET(XFD, &rfds)) {
-      while (XCheckWindowEvent(display, win, ExposureMask|KeyPressMask|ButtonPressMask|StructureNotifyMask, &xev))
+      while (XEventsQueued(display, QueuedAfterReading) > 0) {
+	XNextEvent(display, &xev);
 	doevent(&xev);
+      }
     }
 
     if (FD_ISSET(sfd, &rfds))
@@ -2371,7 +2381,6 @@ void handlemessages() {
 	sysmsg(msgbuf);
 
 	UpdateWinSize();
-	redrawall();
 	break;
       
       case OP_GONE:
@@ -2403,7 +2412,6 @@ void handlemessages() {
 	  }
 
 	  UpdateWinSize();
-	  redrawall();
 
 	  free(u);
 	}
@@ -2625,7 +2633,7 @@ void handlemessages() {
 	s = getid(buf[0]);
 	sprintf(msgbuf, "%s set%s %s mode", s, isyou ? "" : "s", buf[2] ? "fun" : "normal");
 	sysmsg(msgbuf);
-	setmode(buf[2]);
+	set_mode(buf[2]);
 	break;
     }
   }
@@ -2733,7 +2741,7 @@ void sigchld() {
 
 int main(int argc, char *argv[]) {
   int i, j;
-  char *s;
+  char *s, *setnick = NULL;
 
 #ifndef NeXT
   struct sigaction sact;
@@ -2767,12 +2775,14 @@ int main(int argc, char *argv[]) {
 "Use: xtris [options] [server.name [port]]\n"
 "Options:   -display machine:0   --  set the display\n"
 "           -k keys              --  set keys (default is \"JjklL \")\n"
+"           -n nick              --  sets the nickname of the player\n"
 "           -s                   --  standalone mode\n"
 "           -bw                  --  force black & white\n"
 "           -big                 --  bigger squares\n"
 "           -flashy              --  use flashier colors\n"
 "           -norestart           --  pass a -norestart to the server\n"
 "           -nospeedup           --  pass a -nospeedup to the server\n"
+"           -v                   --  show xtris version\n"
 
 );
 
@@ -2781,12 +2791,21 @@ int main(int argc, char *argv[]) {
       sqrsize = 20;
       argv++;
       argc--;
+    } else if (strcmp(argv[1], "-v") == 0) {
+      printf("xtris version " VERSION "\n");
+      exit(0);
     } else if (strcmp(argv[1], "-display") == 0) {
       if (argc < 3)
 	fatal("Missing argument for -display");
       disp = argv[2];
       argv += 2;
       argc -= 2;
+    } else if (strcmp(argv[1], "-n") == 0) {
+      if (argc < 3)
+	fatal("Missing argument for -n");
+      setnick = argv[2];
+      argv += 2;
+      argc -= 2;
     } else if (strcmp(argv[1], "-s") == 0) {
       standalone = 1;
       argv++;
@@ -2853,6 +2872,9 @@ int main(int argc, char *argv[]) {
 
   init_X();
 
+  if (setnick != NULL)
+    strncpy(me.nick, setnick, MAXNICKLEN);
+
   quitbutton = DeclareButton(XBTNS, YQUIT, WBTNS, HBTNS, 0, 1, "Quit", ALIGN_CENTER, c_quit);
   playbutton = DeclareButton(XBTNS, YPLAY, WBTNS, HBTNS, 0, 1, "Start", ALIGN_CENTER, c_play);
   pausebutton = DeclareButton(XBTNS, YPAUSE, WBTNS, HBTNS, 0, 0, "Pause", ALIGN_CENTER, c_pause);
